config

package
v0.0.0-...-68f985e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2026 License: MIT Imports: 4 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConfigPath

func ConfigPath() (string, error)

ConfigPath returns the full path to the config file

func DefaultVaultPath

func DefaultVaultPath() (string, error)

DefaultVaultPath returns the full path to the vault

Types

type Config

type Config struct {
	VaultPath     string `json:"vault_path"`
	Salt          string `json:"salt"`
	ActiveProject string `json:"active_project,omitempty"`
	ActiveEnv     string `json:"active_env,omitempty"`
	ServerURL     string `json:"server_url,omitempty"`
	ServerAPIKey  string `json:"server_api_key,omitempty"`
}

Config represents the global Enveil configuration

func Load

func Load() (*Config, error)

Load reads the config from disk. Returns an empty config if it does not exist

func (*Config) HasServer

func (c *Config) HasServer() bool

HasServer returns whether a server is configured

func (*Config) IsInitialized

func (c *Config) IsInitialized() bool

IsInitialized returns whether Enveil has been set up for the first time

func (*Config) Save

func (c *Config) Save() error

Save writes the config to disk

Jump to