Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetKey ¶
GetKey attempts to retrieve the master key from the daemon Returns the key and true if the daemon is running, empty string and false otherwise
Types ¶
type Request ¶
type Request struct {
Command string `json:"command"`
}
Request is the message the CLI sends to the daemon
type Response ¶
type Response struct {
Success bool `json:"success"`
Key string `json:"key,omitempty"`
Error string `json:"error,omitempty"`
}
Response is the message the daemon sends back to the CLI
Click to show internal directories.
Click to hide internal directories.