Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfigPath ¶
ConfigPath returns the full path to the config file
func DefaultVaultPath ¶
DefaultVaultPath returns the full path to the vault
Types ¶
type Config ¶
type Config struct {
VaultPath string `json:"vault_path"`
Salt string `json:"salt"`
ActiveProject string `json:"active_project,omitempty"`
ActiveEnv string `json:"active_env,omitempty"`
ServerURL string `json:"server_url,omitempty"`
ServerAPIKey string `json:"server_api_key,omitempty"`
}
Config represents the global Enveil configuration
func (*Config) IsInitialized ¶
IsInitialized returns whether Enveil has been set up for the first time
Click to show internal directories.
Click to hide internal directories.